package com.nx.umms.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.nx.umms.common.utils.res.ResultCodeEnum;
import com.nx.umms.common.utils.res.ResultVO;
import com.nx.umms.mapper.ModelTypeMapper;
import com.nx.umms.model.entity.ModelClassify;
import com.nx.umms.service.ModelGroupService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

import java.util.List;

@Service
public class ModelGroupServiceImpl implements ModelGroupService {

    @Autowired
    private ModelTypeMapper modelTypeMapper;

    /**
     * 获取模型类型
     *
     * @return
     */
    @Override
    public ResultVO getModelType() {
        QueryWrapper<ModelClassify> wrapper = new QueryWrapper<>();
        List<ModelClassify> modelClassifyList = modelTypeMapper.selectList(wrapper);
        if (CollectionUtils.isEmpty(modelClassifyList)) {
            return ResultVO.fail(ResultCodeEnum.NO_DATA);
        } else {
            return ResultVO.success(modelClassifyList);
        }
    }

    @Override
    public ResultVO createModelType(ModelClassify modelClassify) {
        int result = modelTypeMapper.insert(modelClassify);
        if (result > 0) {
            return ResultVO.fail(ResultCodeEnum.SUCCESS);
        } else {
            return ResultVO.success(ResultCodeEnum.INSERT_FAIL);
        }
    }

    @Override
    public ResultVO deleteModelType(String modelTypeId) {
        int result = modelTypeMapper.deleteById(modelTypeId);
        if (result > 0) {
            return ResultVO.fail(ResultCodeEnum.ACCESS_DENIED.SUCCESS);
        } else {
            return ResultVO.success(ResultCodeEnum.UNKNOWN);
        }
    }

    @Override
    public ResultVO updateModelType(ModelClassify modelClassify) {
        int result = modelTypeMapper.updateById(modelClassify);
        if (result > 0) {
            return ResultVO.fail(ResultCodeEnum.SUCCESS);
        } else {
            return ResultVO.success(ResultCodeEnum.UP_DATA_FAIL);
        }
    }
}
