package com.nx.umms.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.nx.umms.mapper.ModelVersionMapper;
import com.nx.umms.model.dto.ModelVersionDTO;
import com.nx.umms.model.entity.ModelVersion;
import com.nx.umms.model.vo.ModelVersionVO;
import com.nx.umms.service.ModelVersionService;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;
import java.util.List;
import java.util.stream.Collectors;

/**
 * @Auther: wangjian
 * @Date: 2022/3/28 13:33
 * @Description:
 */

@Service
public class ModelVersionServiceImpl implements ModelVersionService {

    @Autowired
    private ModelVersionMapper modelVersionMapper;

    @Override
    public Integer createModelVersion(ModelVersionDTO modelVersionDTO) {

        ModelVersion modelVersion = new ModelVersion();

        BeanUtils.copyProperties(modelVersionDTO, modelVersion);

        modelVersion.setCreateTime(LocalDateTime.now());
        return modelVersionMapper.insert(modelVersion);
    }

    @Override
    public Integer deleteModelVersion(String mvId, String versionCode) {
        QueryWrapper<ModelVersion> queryWrapper = new QueryWrapper();

        if (StringUtils.isNotEmpty(mvId)) {
            queryWrapper.lambda().eq(ModelVersion::getMvId, mvId);
        }
        if (StringUtils.isNotEmpty(versionCode)) {
            queryWrapper.lambda().eq(ModelVersion::getVersionCode, versionCode);
        }

        return modelVersionMapper.delete(queryWrapper);
    }

    @Override
    public Integer deleteBatchModelVersion(List<String> ids) {
        return modelVersionMapper.deleteBatchIds(ids);
    }

    @Override
    public Integer updateModelVersion(ModelVersionDTO modelVersionDTO) {

        ModelVersion modelVersion = new ModelVersion();

        BeanUtils.copyProperties(modelVersionDTO, modelVersion);

        modelVersion.setUpdateTime(LocalDateTime.now());

        UpdateWrapper<ModelVersion> updateWrapper = new UpdateWrapper<>();

        updateWrapper.lambda().eq(ModelVersion::getMvId, modelVersion.getMvId());

        return modelVersionMapper.update(modelVersion, updateWrapper);
    }

    @Override
    public List<ModelVersionVO> getModelVersionList(String mvId, String versionNumber) {

        QueryWrapper<ModelVersion> queryWrapper = new QueryWrapper();

        if (StringUtils.isNotEmpty(mvId)) {
            queryWrapper.lambda().eq(ModelVersion::getMvId, mvId);
        }

        if (StringUtils.isNotEmpty(versionNumber)) {
            queryWrapper.lambda().eq(ModelVersion::getVersionNumber, versionNumber);
        }

        List<ModelVersion> modelVersionList = modelVersionMapper.selectList(queryWrapper);

        List<ModelVersionVO> modelVersionVOList = modelVersionList.stream().map(t -> {
            ModelVersionVO modelVersionVO = new ModelVersionVO();
            BeanUtils.copyProperties(t, modelVersionVO);
            return modelVersionVO;
        }).collect(Collectors.toList());

        return modelVersionVOList;
    }

    @Override
    public ModelVersion getModelVersion(String mvId, String versionNumber) {
        QueryWrapper<ModelVersion> queryWrapper = new QueryWrapper();

        if (StringUtils.isNotEmpty(mvId)) {
            queryWrapper.lambda().eq(ModelVersion::getMvId, mvId);
        }

        if (StringUtils.isNotEmpty(versionNumber)) {
            queryWrapper.lambda().eq(ModelVersion::getVersionNumber, versionNumber);
        }

        ModelVersionVO modelVersionVO = new ModelVersionVO();

        ModelVersion modelVersion = modelVersionMapper.selectOne(queryWrapper);

//        if (DataHandleUtils.isNullOrEmpty(modelVersion) && StringUtils.isEmpty(modelVersion.getVersionCode())){
//
//        }

//        BeanUtils.copyProperties(modelVersion, modelVersionVO);

        return modelVersion;
    }
}
